'Programm ......... : MC-Kopplung per USB MKU (RL)
'
'
'Programminhalt ... : Testprogramm zur AVR-Kopplung ber USB mit VCP
'                     (serielle Treiber fr FTDI232BL/FTDI232RL)
'
'Programmierer .... : Ingolf Bauer (ingolf.bauer@nexgo.de)
'Version .......... : 1.0
'Datum ............ : 12.11.2007
'
'-------------------------------------------------------------------------------
'
'Historie
'========
'V 1.0 (12.11.2007): - Erstellung
'
'00. Programmspeicher
' - - - - - - - - - -
'    Programmspeicher des MCs (Programm-Flashspeicher): xxx%
'
'-------------------------------------------------------------------------------
'
'Allgemeine Informationen
'========================
'
'01. Anschlu
' - - - - - -
'    Es ist darauf zu achten, da die RXD/TXD-Leitungen zwischen dem USB-Adapter
'    und dem MC gekreuzt sind.
'
'02. Stromversorung
' - - - - - - - - -
'    Je nach Konfiguration des USB-Interface-Bausteins ist eine/keine externe
'    Stromversorgung fr den MC vorzusehen.
'
'-------------------------------------------------------------------------------
'
'I/O-Ports
'=========
' AE/ AA: analoger  Ein-/ Ausgang
' DE/ DA: digitaler Ein-/ Ausgang
' PRG   : Programmierung (Signale MOSI, MISO, SCK, Reset)
' RXD   : Empfangsleitung
' TXD   : Sendeleitung
'
'==Port B  Funktion      | Signal        | Erluterung                    | Pin
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' - .0: .. ............. | ............. | .............................. | 14
' - .1: .. ............. | ............. | .............................. | 15
' - .2: .. ............. | ............. | .............................. | 16
' - .3: -- PRG ......... | MOSI ........ | .............................. | 17
' - .4: -- PRG ......... | MISO ........ | .............................. | 18
' - .5: -- PRG ......... | SCK ......... | .............................. | 19
'
'==Port C  Funktion      | Signal        | Erluterung                    | Pin
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' - .0: .. ............. | ............. | .............................. | 23
' - .1: .. ............. | ............. | .............................. | 24
' - .2: .. ............. | ............. | .............................. | 25
' - .3: .. ............. | ............. | .............................. | 26
' - .4: .. ............. | ............. | .............................. | 27
' - .5: .. ............. | ............. | .............................. | 28
' - .6: -- PRG ......... | RESET ....... | Reset (optionale Einstellung)  | 01
'
'==Port D  Funktion      | Signal        | Erluterung                    | Pin
' - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
' - .0: DE RXD ......... | RXD ......... | Empfangsleitung .............. | 02
' - .1: DA TXD ......... | TXD ......... | Sendeleitung ................. | 03
' - .2: .. ............. | ............. | .............................. | 04
' - .3: .. ... ......... | ............. | .............................. | 05
' - .4: .. ... ......... | ............. | .............................. | 06
' - .5: .. ... ......... | ............. | .............................. | 07
' - .6: .. ... ......... | ............. | .............................. | 08
' - .7: .. ... ......... | ............. | .............................. | 09
'
'-------------------------------------------------------------------------------
'
'03. Einstellung der FUSE-Bits mit TwinAvr
'-----------------------------------------
' - Frequenzeinstellung (extern, Quarz)
'   CKSEL0 ........... : Haken ist gesetzt (Lieferzustand)
'   CKSEL1- CKSEL3 ... : Haken setzen (111) bei Quarzfrequenz 8,0 MHz

'   Achtung!
'   ========
'   Wenn aus Versehen CKSEL3=0 gesetzt wurde, arbeitet der MC nur noch mit einem
'   externen RC-Generator [f= 1/(3RC); C>= 22p].
'
' - JTAG(EN)
'   JTAGEN ........... : Haken setzen (Lieferzustand: Haken ist nicht gesetzt)
'
'   ACHTUNG!
'   ========
'   Beim ATmega16 wird das JTAG(EN) Flag defaultmig auf Enable gesetzt. Dies
'   bedeutet, da das JTAG-Interface (prozenahe Datenabfrage) aktiviert ist.
'   Dann kann aber Port C fr keine anderen Aufgaben genutzt werden!
'   Wie und ob das Flag programmig verndert werden kann, ist mir nicht be-
'   kannt. Auf alle Flle kann es ausgeschaltet werden, wenn unter "Configura-
'   tion" beim AVR-Programmer ein Haken bei JTAGEN gesetzt wird.
'
'04. Anschluschema fr den AVR ATmega16
'---------------------------------------
'
'                         --------------|_|--------------
'                        | 1 [PB0]               [PA0] 40|
'                        | 2 [PB1]               [PA1] 39|
'                        | 3 [PB2, INT2]         [PA2] 38|
'                        | 4 [PB3, OC0]          [PA3] 37|
'                        | 5 [PB4]               [PA4] 36|
'          PRG_MOSI ---> | 6 [PB5, MOSI]         [PA5] 35|
'          PRG_MISO <--- | 7 [PB6, MISO]         [PA6] 34|
'          PRG_SCK  ---> | 8 [PB7, SCK]          [PA7] 33|
'          PRG_RESET---> | 9 [/Reset]           [AREF] 32| ==== KON_A (analog)
'             P5V_D ==== |10 [VCC]              [AGND] 31| ==== GND_A (analog)
'             GND_D ==== |11 [GND]              [AVCC] 30| ==== P5V_A (analog)
'                QZ ++++ |12 [XTAL2]             [PC7] 29|
'                QZ ++++ |13 [XTAL1]             [PC6] 28|
'               RXD ---> |14 [PD0, RXD]          [PC5] 27|
'               TXD <--- |15 [PD1, TXD]          [PC4] 26|
'                        |16 [PD2, INT0]         [PC3] 25|
'                        |17 [PD3, INT1]         [PC2] 24|
'                        |18 [PD4]               [PC1] 23|
'                        |19 [PD5]               [PC0] 22|
'                        |20 [PD6]               [PD7] 21|
'                         -------------------------------

' P5V/ (analog) ..... : Versorgungsspannung +5 V, stabilisiert
' GND/ (analog) ..... : Masse der Versorgungsspannung
'
'-------------------------------------------------------------------------------
'
'Definition
   $regfile = "m16def.dat"                        'Prozessor ....... : ATmega16
   $crystal = 4000000                             'Quarzfrequenz ... : 4,0 MHz
   $baud = 9600                                   'UART Baudrate: 9600 Baud
'
'-------------------------------------------------------------------------------
'
'Deklaration
'=Konstante
    Dim I As Integer                              'Hilfsvariable 01
    Dim J As Integer                              'Hilfsvariable 02
    Dim R232_byte As Byte                         'R232: empfangenes Byte
'
'-------------------------------------------------------------------------------
'
'Initialisierung
'=I/O-Ports
'==Port B
'-Datenrichtung (Ein [0]: Eingang, Aus [1]: Ausgang)
   Ddrb = &B0000_0111                             'PB3-7 Ein, PB0-2 Aus
'-Pullup-Widerstand (passiv [0], aktiv [1])
   Portb = &B0001_0000                            'PB0-3, 5-7 passiv, PB4 aktiv
'
'=Interrupts
   On Urxc Int_rxd                                'Interrupt-Routine URXC
   Enable Urxc                                    'Interrupts URXC einschalten
   Enable Interrupts                              'Interrupts global zulassen
'
'-------------------------------------------------------------------------------
'
'Programm
Do
'Anzeige, da MC luft
' Blinken
   Portb.0 = 1
   Waitms 300
   Portb.0 = 0
   Portb.1 = 1
   Waitms 300
   Portb.1 = 0
   Portb.2 = 1
   Waitms 300
   Portb.2 = 0
Loop

End                                               'Programmende

'-------------------------------------------------------------------------------
'=== I N T E R R U P T S  ======================================================
'-------------------------------------------------------------------------------
'=INT-Routine (URXC):
Int_rxd:
   R232_byte = Udr                                'Byte aus der UART auslesen
   Select Case R232_byte
      Case 65                                     'Taste "A" am PC gedrckt
         Gosub Up_senden                          'UP anspringen
   End Select

Return
'
'-------------------------------------------------------------------------------
'=== U N T E R P R O G R A M M E ===============================================
'-------------------------------------------------------------------------------
'
Up_senden:
'Daten ber die serielle Schnittstelle an den PC senden
'nur aktiviert, wenn PB4 = H
   If Pinb.4 = 1 Then
      For I = 1 To 255                            'Zahlen bertragen
         J = 255 - I                              'Testzeile
         Print I                                  'Datenausgabe ber RS232
      Next I
   End If

Return

'Programmende